@@ -104,12 +104,9 @@ static bool do_assignment(const word_T *word, const value_T *value)
     __attribute__((nonnull));
 static wchar_t *value_to_string(const value_T *value)
     __attribute__((nonnull));
-static long do_long_calculation(tokentype_T ttype, long v1, long v2)
-    __attribute__((nonnull));
-static double do_double_calculation(tokentype_T ttype, double v1, double v2)
-    __attribute__((nonnull));
-static long do_double_comparison(tokentype_T ttype, double v1, double v2)
-    __attribute__((nonnull));
+static long do_long_calculation(tokentype_T ttype, long v1, long v2);
+static double do_double_calculation(tokentype_T ttype, double v1, double v2);
+static long do_double_comparison(tokentype_T ttype, double v1, double v2);
 static void parse_conditional(evalinfo_T *info, value_T *result)
     __attribute__((nonnull));
 static void parse_logical_or(evalinfo_T *info, value_T *result)
@@ -823,7 +820,12 @@ void parse_prefix(evalinfo_T *info, value_T *result)
 	case TT_MINUSMINUS:
 	    next_token(info);
 	    parse_prefix(info, result);
-	    if (result->type == VT_VAR) {
+	    if (posixly_correct) {
+		xerror(0, Ngt("arithmetic: operator `%ls' is not supported"),
+			(ttype == TT_PLUSPLUS) ? L"++" : L"--");
+		info->error = true;
+		result->type = VT_INVALID;
+	    } else if (result->type == VT_VAR) {
 		word_T saveword = result->v_var;
 		coerce_number(info, result);
 		do_increment_or_decrement(ttype, result);
@@ -893,7 +895,13 @@ void parse_postfix(evalinfo_T *info, value_T *result)
 	switch (info->token.type) {
 	    case TT_PLUSPLUS:
 	    case TT_MINUSMINUS:
-		if (result->type == VT_VAR) {
+		if (posixly_correct) {
+		    xerror(0,
+			    Ngt("arithmetic: operator `%ls' is not supported"),
+			    (info->token.type == TT_PLUSPLUS) ? L"++" : L"--");
+		    info->error = true;
+		    result->type = VT_INVALID;
+		} else if (result->type == VT_VAR) {
 		    word_T saveword = result->v_var;
 		    coerce_number(info, result);
 		    value_T value = *result;
